Class: ResultParser
- Inherits:
-
Object
- Object
- ResultParser
- Defined in:
- lib/ci_helper/result_parser.rb
Overview
This class handle the the result page in the to see the result of test and failures
This class handle the the result page in the to see the result of test and failures